#
# spec file for package librime
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           librime
Version:        1.2.9+git20160226.df4192c
Release:        1.43
Summary:        Rime Input Method Engine
License:        BSD-3-Clause
Group:          System/I18n/Chinese
Url:            https://github.com/rime/librime
Source:         %{name}-%{version}.tar.xz
#PATCH-FIX-OPENSUSE workaround for gcc bug 53613 on 12.3 and lower
Patch1:         librime-1.1-gcc53613.patch
#PATCH-FIX-OPENSUSE fix boost 1.49 filesystem linking on 12.3 and lower
Patch2:         librime-1.2-BOOST_NO_SCOPED_ENUMS.patch
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_locale-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_signals-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  glog-devel
BuildRequires:  googletest-devel
BuildRequires:  leveldb-devel
BuildRequires:  libkyotocabinet-devel
BuildRequires:  marisa-devel
BuildRequires:  opencc-devel >= 1.0.2
BuildRequires:  pkg-config
BuildRequires:  xorg-x11-proto-devel
BuildRequires:  yaml-cpp-devel
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Rime is an Traditional Chinese input method engine.
Its idea comes from ancient Chinese brush and carving art.
Mainly it's about to express your thinking with your keystrokes.

%package -n rime
Summary:        Rime Input Method Engine
Group:          System/I18n/Chinese

%description -n rime
Rime is an Traditional Chinese input method engine.
Its idea comes from ancient Chinese brush and carving art.
Mainly it's about to express your thinking with your keystrokes.

%package -n librime1
Summary:        Rime Input Method Engine
Group:          System/Libraries

%description -n librime1
Rime is an Traditional Chinese input method engine.
Its idea comes from ancient Chinese brush and carving art.
Mainly it's about to express your thinking with your keystrokes.

This package is the runtime libraries of Rime.

%package devel
Summary:        Development files of Rime
Group:          Development/Libraries/C and C++
Requires:       librime1 = %{version}
Requires:       rime = %{version}

%description devel
Rime is an Traditional Chinese input method engine.
Its idea comes from ancient Chinese brush and carving art.
Mainly it's about to express your thinking with your keystrokes.

This package is the development headers of Rime.

%prep
%setup -q
%if 0%{?suse_version} <= 1230
%patch1 -p1
%patch2 -p1
%endif
sed -i "s/1.46.0/1.36.0/" CMakeLists.txt

%build
%cmake \
  -DCMAKE_BUILD_TYPE=RelWithDebInfo
make %{?_smp_mflags}

%install
%cmake_install

%post -n librime1 -p /sbin/ldconfig
%postun -n librime1 -p /sbin/ldconfig

%files -n rime
%defattr(-,root,root)
%doc LICENSE README.md
%{_bindir}/rime_deployer
%{_bindir}/rime_dict_manager

%files -n librime1
%defattr(-,root,root)
%{_libdir}/%{name}.so.1
%{_libdir}/%{name}.so.1.2.9

%files devel
%defattr(-,root,root)
%{_includedir}/rime_api.h
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/rime.pc
%{_datadir}/cmake/rime/

%changelog
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Mar 17 2016 mpluskal@suse.com
- Use cmake macros
- Drop useless conditional build dependencies for non-devel
  packages
* Mon Mar 14 2016 qzhao@suse.com
- Change LICENSE from GPL-3.0+ to BSD-3-Clause to keep consistent
  with upstream.
* Wed Mar  2 2016 i@marguerite.su
- Update to version 1.2.9+git20160226.df4192c:
  + pass function argument by value instead of by const reference.
  + (feature) translation past caret pos.
  + (fix) in horizontal mode, right arrow key should not fall back
    to moving caret when reached the end of candidate list.
  + (feature) jump left by word only at stops of multiple spans.
  + (feature) set caret between preedit and prompt string.
  + (tools) show caret pos in rime_api_console.
  + (fix) caret on the left side of input or the selected range.
  + Fix issue #64.
  + Add a comment for explanation.
* Tue Aug 11 2015 i@marguerite.su
- update version 1.2.9+git20140802.ee3029e
* Tue Feb 24 2015 hillwood@linuxfans.org
- update to 1.2.9
  * CMakeLists.txt: bump version to 1.2.9.
  * Makefile: add make targets 'thirdparty/*' to build individual libraries.
  * include/rime_api.h: add RIME_MODULE_LIST, RIME_REGISTER_MODULE_GROUP.
  * legacy/src/legacy_module.cc: plugin module 'rime-legacy' for GPL'd code,
    providing component 'legacy_userdb' for user dictionary upgrade.
  * src/setup.cc: define module groups "default" and "deployer", to avoid
    naming a list of built-bin modules in RimeTraits::modules.
  * test/table_test.cc: fix random segment faults when run shuffled.
  * thirdparty/src/leveldb: new dependency LevelDB, replacing Kyoto Cabinet.
  * dict/level_db: userdb implementation based on LevelDB, replacing treeDb.
  * dict/tree_db: moved to legacy/src/.
  * dict/user_db: refactored and modularized to ease adding implementations.
  * gear/memory: save cached phrases as soon as the next composition begins.
  * gear/recognizer: match space iff set recognizer/use_space: true.
  * gear/simplifier: catch and log OpenCC exceptions when loading.
  * gear/single_char_filter: bring single character candidates to the front.
  * lever/deployment_tasks: update and rename task 'user_dict_upgrade'.
  * gear/cjk_minifier: support CJK Extension E
  * gear/simplifier: adapt to OpenCC 1.0 API.
  * thirdparty/src/opencc: update OpenCC to v1.0.2 (incompatible with v0.4).
* Sun Aug 10 2014 i@marguerite.su
- update version 1.2+git20140810
  * config: support references to list elements in key paths.
  * rime_api: add API functions to access complex structures
    in config; add API to get the raw input and cursor
    position, or to select a candidate.
  * switcher: enable folding IME options in the switcher menu.
  * dict_compiler: also detect changes in essay when updating
    a dictionary; support updating prism without the source
    file of the dictionary.
  * preset_vocabulary: load 'essay.txt' instead of 'essay.kct'.
  * reverse_lookup_dictionary: adopt a new file format with
    50%% space saving.
  * table: add support for a new binary format with 20%% space
    saving; fix alignment on ARM.
  * ascii_composer: do not toggle IME states when long pressing
    Shift key; support discarding unfinished input when
    switching to ASCII mode.
  * affix_segmentor: fix issues with selecting a partial-match
    candidate.
  * chord_composer: commit raw input composed with original
    key strokes.
  * navigator: do not use BackSpace to revert selecting a
    candidate but to edit the input after moving the cursor
    left or right.
  * punctuator: support 'ascii_punct' option for switching
    between Chinese and Western (ASCII) punctuations.
  * speller: auto-select candidates by pattern matching against
    the code; fix issues to cooperate with punctuator.
  * CMakeLists.txt: add options ENABLE_LOGGING and BOOST_USE_CXX11;
    introduce a new dependency: libmarisa.
  * cmake/FindYamlCpp.cmake: check the availability of the
    new (v0.5) API.
  * sample: the directory containing a sample plug-in module.
  * tools/rime_patch.cc: a command line tool to create patches.
- drop librime-1.1-BOOST_NO_SCOPED_ENUMS.patch
- add librime-1.2-BOOST_NO_SCOPED_ENUMS.patch
* Wed Mar  5 2014 i@marguerite.su
- update version 1.1git20140306
  * new build dependency: compiler with C++11 support.
    tested with GCC 4.8.2, Apple LLVM version 5.0, MSVC 12 (2013).
  * encoder: disable warnings for phrase encode failures in log output;
    limit the number of results in encoding a phrase with multiple solutions.
  * punctuator: fixed a bug in matching nested "pairs of 'symbols'".
  * speller: better support for auto-committing, allowing users of table
    based input schemata to omit explicitly selecting candidates in many cases.
  * schema_list_translator: option for static schema list order.
  * table_translator: fixed the range of CJK-D in charset filter.
- added patch librime-1.1-gcc53613.patch
  * workaround for gcc bug 53613: Cannot override a inline "= default"
    virtual destructor.
- added patch librime-1.1-BOOST_NO_SCOPED_ENUMS.patch
  * fix boost 1.49 filesystem linking on 12.3 and lower
* Mon Nov 11 2013 i@marguerite.su
- update version 1.0
  * rime_api: version 1.0 breaks ABI compatiblility.
    the minimum changes in code required to migrate from rime 0.9 api is
    to initialize RimeTraits with either RIME_STRUCT or RIME_STRUCT_INIT macro.
    while source code compatibility is largely maintained with the exception
    of the aforementioned RimeTraits structure, rime 1.0 introduces a version
    controlled RimeApi structure which provides all the api functions.
  * module: suppport adding modules; modulize 'gears' and 'levers'.
  * ticket: used to instantiate compnents and to associate the instance with
    a name space in the configuration.
  * encoder: encode new phrases for table_translator and script_translator
    using different rules.
  * affix_segmentor: strip optional prefix and suffix from a code segment.
  * reverse_lookup_filter: lookup candidate text for code in a specified
    dictonary.
  * shape: add full-shape support.
  * key_binder: switch input schemata and toggle options with hotkeys.
  * switcher: list input schemata ordered by recency; support radio options.
  * tsv: fix reading user dict snapshot files with DOS line endings.
  * entry_collector: support custom order of table columns in *.dict.yaml.
  * CMakeLists.txt: add options BUILD_TEST and BUILD_SEPARATE_LIBS.
- removed patch: librime-0.9.9-fail_gtest.patch
  * upstreamed
* Sat Jun 29 2013 i@marguerite.su
- update version 0.9.9
  * config: update yaml-cpp to version 0.5 (with new API);
    emit prettier yaml.
  * deployer: introduce a work thread for ordinary background tasks.
  * algo/calculus: 'fuzz' calculation, to create lower quality spellings.
  * dict/dict_compiler: importing external table files into *.dict.yaml.
  * dict/entry_collector: support '# no comment' directive in *.dict.yaml.
  * dict/table_db: 'tabledb' and 'stabledb' to support custom phrase.
  * dict/user_db: implement 'plain_userdb', in plain text files.
  * dict/user_dictionary: recover damaged userdb in work thread.
  * gear/ascii_composer: fix unexpected mode switching with Caps Lock.
  * gear/editor: delete previous syllable with Control+BackSpace.
  * gear/*_translator: support multiple translator instances in a engine.
  * gear/script_translator: rename r10n_translator to script_translator.
  * lever/user_dict_manager: create snapshots in plain userdb format.
  * rime_deployer: with command line option '--compile',
    dump table/prism contents into text files while compiling a dictionary.
* Sat Jun 15 2013 schwab@linux-m68k.org
- Build with %%{optflags}
* Thu Jun  6 2013 coolo@suse.com
- do not hardcode boost sonames
* Thu Oct 11 2012 i@marguerite.su
- update version 0.9.4
  * document new dependency 'google-glog'.
  * fix x64 build.
* Sun Aug 12 2012 i@marguerite.su
- dependency name changed from gtest-devel to googletest-devel.
* Sat Jul 21 2012 i@marguerite.su
- initial version 0.9.2
  * chord-typing support: combine multiple keys to compose a syllable at once.
  * configuration: global page_size setting.
  * inline mode: extend the API to support inline mode.
  * table translator: add option to filter candidates by character set.
  * user dictionary: automatic recovery for corrupted databases.
  * user dictionary: fixed a bug that was responsible for missing user phrases.
  * rime_deployer: a utility program to prepare Rime's workspace.
  * rime_dict_manager: a utility program to import/export user dictionaries.
  * librime package: include 'brise', a collection of preset schemata in the package.
  * new schema: Middle Chinese Phonetic Transcription.
  * new schema: IPA input method in X-SAMPA.
